pycocoa.printers.PaperMargins

Package pycocoa :: Module printers :: Class PaperMargins |
[frames] | no frames]

# Class PaperMargins

       object --+
                |
        ??._CData --+
                    |
    _ctypes.Structure --+
                        |
       octypes.c_struct_t --+
                            |
                     PMRect_t --+
                                |
                               PaperMargins

Python `PaperMargins` Type, wrapping an ObjC `PMPaperMargins`.

Instance Methods
__init__(self, margins_pm=None, bottom=0, left=0, right=0, top=0) New PaperMargins from margin attributes. |
Inherited from `octypes.c_struct_t`: `__repr__`, `__str__` Inherited from `_ctypes.Structure`: `__new__` Inherited from `_CData`: `__ctypes_from_outparam__`, `__hash__`, `__reduce__`, `__setstate__` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables
Inherited from `PMRect_t`: `bottom`, `left`, `right`, `top`

Properties
| PM N/A
Inherited from `object`: `__class__`

Method Details

### __init__(self, margins_pm=None, bottom=0, left=0, right=0, top=0) (Constructor) |
New PaperMargins from margin attributes. Raises: `TypeError` - Invalid margins_pm. Overrides: object.__init__

Property Details

### PM N/A Get Method: PM(self) Set Method: Read_Only(inst, value) - Throws an `AttributeError`, always.